@@ -36,6 +36,7 @@ class DynamicPlaylist;
 class PlaylistItem;
 class Playlist;
 class PlayerManager;
+class FileHandle;
 
 template<class T>
 class QList;
@@ -107,7 +108,8 @@ public:
 
     virtual PlaylistItemList selectedItems();
 
-    void scanFolders();
+    // virtual to allow our QWidget subclass to emit a signal after we're done
+    virtual void scanFolders();
 
     void createPlaylist();
     void createSearchPlaylist();
